/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Model - SearchCondition.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.solidify.rest;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class SearchCondition implements Serializable {

  private static final long serialVersionUID = 5537263935227896080L;

  /**
   * Indicate whether the condition is used to find documents that match or don't match its value
   */
  private SearchConditionType type = SearchConditionType.MATCH;

  /**
   * name of the field to query
   */
  private String field;

  /**
   * value if we search a single value
   */
  private String equalValue;

  /**
   * Values if we search documents having one of the values in the list
   */
  private final List<String> equalValues = new ArrayList<>();

  /**
   * Upper value with we search a range of possible values
   */
  private String upperValue;

  /**
   * Lower if we search a range of possible values
   */
  private String lowerValue;

  /**
   * Describe a search condition that is a full query (instead of a single field matching some
   * conditions)
   */
  private String query;

  public SearchCondition() {
  }

  public SearchCondition(SearchConditionType type) {
    this.type = type;
  }

  public SearchCondition(SearchConditionType type, String field) {
    this.type = type;
    this.field = field;
  }

  public SearchCondition(SearchConditionType type, String field, String equalValue) {
    this.type = type;
    this.field = field;
    this.equalValue = equalValue;
  }

  public SearchCondition(SearchConditionType type, String field, List<String> equalValues) {
    this.type = type;
    this.field = field;
    if (equalValues != null) {
      this.equalValues.addAll(equalValues);
    }
  }

  public SearchConditionType getType() {
    return this.type;
  }

  public void setType(SearchConditionType type) {
    this.type = type;
  }

  public String getField() {
    return this.field;
  }

  public void setField(String field) {
    this.field = field;
  }

  public String getEqualValue() {
    return this.equalValue;
  }

  public void setEqualValue(String equalValue) {
    this.equalValue = equalValue;
  }

  public List<String> getEqualValues() {
    return this.equalValues;
  }

  public String getUpperValue() {
    return this.upperValue;
  }

  public void setUpperValue(String upperValue) {
    this.upperValue = upperValue;
  }

  public String getLowerValue() {
    return this.lowerValue;
  }

  public void setLowerValue(String lowerValue) {
    this.lowerValue = lowerValue;
  }

  public String getQuery() {
    return this.query;
  }

  public void setQuery(String query) {
    this.query = query;
  }
}
